;; Generated package description from evil-collection.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "evil-collection" "3.0.0.0.20260719.2" "A set of keybindings for Evil mode" '((emacs "29.1") (evil "1.2.13")) :commit "03e1c04b398bc8948a21fac5f3baa4f70da1a350" :authors '(("James Nguyen" . "james@jojojames.com")) :maintainer '("James Nguyen" . "james@jojojames.com") :keywords '("evil" "tools") :url "https://github.com/emacs-evil/evil-collection")
